@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,8 +23,8 @@ class CControllerImageCreate extends CController {
 
 	protected function checkInput() {
 		$fields = [
-			'name'      => 'required | not_empty | db images.name',
-			'imagetype' => 'required | fatal | db images.imagetype'
+			'name'      => 'required|not_empty|db images.name',
+			'imagetype' => 'required|fatal|db images.imagetype'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -56,12 +56,6 @@ class CControllerImageCreate extends CController {
 			return false;
 		}
 
-		$this->image = [
-			'imageid'   => 0,
-			'imagetype' => $this->getInput('imagetype'),
-			'name'      => $this->getInput('name', '')
-		];
-
 		return true;
 	}
 
@@ -106,28 +100,34 @@ class CControllerImageCreate extends CController {
 			$response->setFormData($this->getInputAll());
 			CMessageHelper::setErrorTitle(_('Cannot add image'));
 
-			return $this->setResponse($response);
+			$this->setResponse($response);
+			return;
 		}
 
-		$result = API::Image()->create([
+		$options = [
 			'imagetype' => $this->getInput('imagetype'),
-			'name'      => $this->getInput('name'),
-			'image'     => $image
-		]);
+			'name' => $this->getInput('name')
+		];
+
+		if ($image != null) {
+			$options['image'] = $image;
+		}
+
+		$result = API::Image()->create($options);
 
 		if ($result) {
-			add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_IMAGE, 'Image ['.$this->getInput('name').'] created');
-
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', 'image.list')
-				->setArgument('imagetype', $this->getInput('imagetype'))
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'image.list')
+					->setArgument('imagetype', $this->getInput('imagetype'))
 			);
 			CMessageHelper::setSuccessTitle(_('Image added'));
 		}
 		else {
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', 'image.edit')
-				->setArgument('imagetype', $this->getInput('imagetype'))
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'image.edit')
+					->setArgument('imagetype', $this->getInput('imagetype'))
 			);
 			$response->setFormData($this->getInputAll());
 			CMessageHelper::setErrorTitle(_('Cannot add image'));
