@@ -1,4 +1,4 @@
-<?php declare(strict_types = 1);
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
 ** Copyright (C) 2001-2022 Zabbix SIA
@@ -116,10 +116,10 @@ $('#tabs').on('tabsactivate', (event, ui) => {
 		obj = tags_elem.originalObject;
 	}
 
-	$(obj.querySelector('#tags-table')).dynamicRows({template: '#tag-row-tmpl'});
-	$(obj.querySelector('#tags-table'))
+	$(obj.querySelector('.tags-table')).dynamicRows({template: '#tag-row-tmpl'});
+	$(obj.querySelector('.tags-table'))
 		.on('click', 'button.element-table-add', () => {
-			$('#tags-table .<?= ZBX_STYLE_TEXTAREA_FLEXIBLE ?>').textareaFlexible();
+			$('.tags-table .<?= ZBX_STYLE_TEXTAREA_FLEXIBLE ?>').textareaFlexible();
 		})
 		.on('resize', '.<?= ZBX_STYLE_TEXTAREA_FLEXIBLE ?>', () => {
 			$(window).resize();
@@ -449,9 +449,12 @@ function submitPopup(overlay) {
 			$('head').append(response.script_inline);
 		}
 
-		if ('errors' in response) {
+		if ('error' in response) {
 			overlay.unsetLoading();
-			$(response.errors).insertBefore(form);
+
+			const message_box = makeMessageBox('bad', response.error.messages, response.error.title);
+
+			message_box.insertBefore(form);
 		}
 		else {
 			postMessageOk(response.title);
