@@ -234,7 +234,7 @@ class CTask extends CApiService {
 										'proxy_hostids' =>	['type' => API_IDS, 'flags' => API_REQUIRED | API_NOT_EMPTY, 'uniq' => true]
 									]],
 									['if' => ['field' => 'type', 'in' => ZBX_TM_DATA_TYPE_CHECK_NOW], 'type' => API_OBJECT, 'fields' => [
-										'itemid' => ['type' => API_ID, 'flags' => API_REQUIRED | API_NOT_EMPTY]
+										'itemid' => ['type' => API_ID, 'flags' => API_REQUIRED]
 									]]
 								]],
 			'proxy_hostid' =>	['type' => API_ID, 'default' => 0]
