@@ -1,7 +1,7 @@
-<?php
+<?php declare(strict_types = 0);
 /*
 ** Zabbix
-** Copyright (C) 2001-2021 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,31 +21,37 @@
 
 /**
  * Graph prototype widget form view.
+ *
+ * @var CView $this
+ * @var array $data
  */
+
 $fields = $data['dialogue']['fields'];
 
 $form = CWidgetHelper::createForm();
 
-$rf_rate_field = ($data['templateid'] === null) ? $fields['rf_rate'] : null;
-
-$form_list = CWidgetHelper::createFormList($data['dialogue']['name'], $data['dialogue']['type'],
-	$data['dialogue']['view_mode'], $data['known_widget_types'], $rf_rate_field
-);
-
 $scripts = [];
 
-// Source.
-$form_list->addRow(
-	CWidgetHelper::getLabel($fields['source_type']),
-	CWidgetHelper::getRadioButtonList($fields['source_type'])
+$form_grid = CWidgetHelper::createFormGrid($data['dialogue']['name'], $data['dialogue']['type'],
+	$data['dialogue']['view_mode'], $data['known_widget_types'],
+	$data['templateid'] === null ? $fields['rf_rate'] : null
 );
 
+// Source.
+$form_grid->addItem([
+	CWidgetHelper::getLabel($fields['source_type']),
+	new CFormField(CWidgetHelper::getRadioButtonList($fields['source_type']))
+]);
+
 // Graph prototype.
 if (array_key_exists('graphid', $fields)) {
 	$field_graphid = CWidgetHelper::getGraphPrototype($fields['graphid'],
 		$data['captions']['ms']['graph_prototypes']['graphid'], $form->getName()
 	);
-	$form_list->addRow(CWidgetHelper::getMultiselectLabel($fields['graphid']), $field_graphid);
+	$form_grid->addItem([
+		CWidgetHelper::getMultiselectLabel($fields['graphid']),
+		new CFormField($field_graphid)
+	]);
 	$scripts[] = $field_graphid->getPostJS();
 }
 
@@ -54,22 +60,40 @@ if (array_key_exists('itemid', $fields)) {
 	$field_itemid = CWidgetHelper::getItemPrototype($fields['itemid'],
 		$data['captions']['ms']['item_prototypes']['itemid'], $form->getName()
 	);
-	$form_list->addRow(CWidgetHelper::getMultiselectLabel($fields['itemid']), $field_itemid);
+	$form_grid->addItem([
+		CWidgetHelper::getMultiselectLabel($fields['itemid']),
+		new CFormField($field_itemid)
+	]);
 	$scripts[] = $field_itemid->getPostJS();
 }
 
 // Show legend.
-$form_list->addRow(CWidgetHelper::getLabel($fields['show_legend']), CWidgetHelper::getCheckBox($fields['show_legend']));
+$form_grid->addItem([
+	CWidgetHelper::getLabel($fields['show_legend']),
+	new CFormField(CWidgetHelper::getCheckBox($fields['show_legend']))
+]);
 
 // Dynamic item.
 if ($data['templateid'] === null) {
-	$form_list->addRow(CWidgetHelper::getLabel($fields['dynamic']), CWidgetHelper::getCheckBox($fields['dynamic']));
+	$form_grid->addItem([
+		CWidgetHelper::getLabel($fields['dynamic']),
+		new CFormField(CWidgetHelper::getCheckBox($fields['dynamic']))
+	]);
 }
 
-// Columns and Rows.
-CWidgetHelper::addIteratorFields($form_list, $fields['columns'], $fields['rows']);
+// Columns.
+$form_grid->addItem([
+	CWidgetHelper::getLabel($fields['columns']),
+	new CFormField(CWidgetHelper::getIntegerBox($fields['columns']))
+]);
 
-$form->addItem($form_list);
+// Rows.
+$form_grid->addItem([
+	CWidgetHelper::getLabel($fields['rows']),
+	new CFormField(CWidgetHelper::getIntegerBox($fields['rows']))
+]);
+
+$form->addItem($form_grid);
 
 return [
 	'form' => $form,
