@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2022 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -27,10 +27,8 @@
  * @return string
  */
 function getUserTheme($userData) {
-	$config = select_config();
-
-	if (isset($config['default_theme'])) {
-		$css = $config['default_theme'];
+	if (null !== CSettingsHelper::getGlobal(CSettingsHelper::DEFAULT_THEME)) {
+		$css = CSettingsHelper::get(CSettingsHelper::DEFAULT_THEME);
 	}
 	if (isset($userData['theme']) && $userData['theme'] != THEME_DEFAULT) {
 		$css = $userData['theme'];
@@ -47,13 +45,13 @@ function getUserTheme($userData) {
  *
  * @param int $userType
  *
- * @return string
+ * @return string|array
  */
 function user_type2str($userType = null) {
 	$userTypes = [
-		USER_TYPE_ZABBIX_USER => _('Zabbix User'),
-		USER_TYPE_ZABBIX_ADMIN => _('Zabbix Admin'),
-		USER_TYPE_SUPER_ADMIN => _('Zabbix Super Admin')
+		USER_TYPE_ZABBIX_USER => _('User'),
+		USER_TYPE_ZABBIX_ADMIN => _('Admin'),
+		USER_TYPE_SUPER_ADMIN => _('Super admin')
 	];
 
 	if ($userType === null) {
@@ -82,25 +80,13 @@ function user_auth_type2str($authType) {
 	$authUserType = [
 		GROUP_GUI_ACCESS_SYSTEM => _('System default'),
 		GROUP_GUI_ACCESS_INTERNAL => _x('Internal', 'user type'),
+		GROUP_GUI_ACCESS_LDAP => _('LDAP'),
 		GROUP_GUI_ACCESS_DISABLED => _('Disabled')
 	];
 
 	return isset($authUserType[$authType]) ? $authUserType[$authType] : _('Unknown');
 }
 
-/**
- * Unblock user account.
- *
- * @param array $userIds
- *
- * @return bool
- */
-function unblock_user_login($userIds) {
-	zbx_value2array($userIds);
-
-	return DBexecute('UPDATE users SET attempt_failed=0 WHERE '.dbConditionInt('userid', $userIds));
-}
-
 /**
  * Get users ids by groups ids.
  *
@@ -142,10 +128,10 @@ function granted2update_group($userGroupIds) {
 }
 
 /**
- * Gets user full name in format "alias (name surname)". If both name and surname exist, returns translated string.
+ * Gets user full name in format "username (name surname)". If both name and surname exist, returns translated string.
  *
  * @param array  $userData
- * @param string $userData['alias']
+ * @param string $userData['username']
  * @param string $userData['name']
  * @param string $userData['surname']
  *
@@ -154,7 +140,9 @@ function granted2update_group($userGroupIds) {
 function getUserFullname($userData) {
 	if (!zbx_empty($userData['surname'])) {
 		if (!zbx_empty($userData['name'])) {
-			return $userData['alias'].' '._x('(%1$s %2$s)', 'user fullname', $userData['name'], $userData['surname']);
+			return $userData['username'].' '._xs('(%1$s %2$s)', 'user fullname', $userData['name'],
+				$userData['surname']
+			);
 		}
 
 		$fullname = $userData['surname'];
@@ -163,7 +151,7 @@ function getUserFullname($userData) {
 		$fullname = zbx_empty($userData['name']) ? '' : $userData['name'];
 	}
 
-	return zbx_empty($fullname) ? $userData['alias'] : $userData['alias'].' ('.$fullname.')';
+	return zbx_empty($fullname) ? $userData['username'] : $userData['username'].' ('.$fullname.')';
 }
 
 /**
@@ -182,7 +170,7 @@ function getHostGroupsRights(array $usrgrpids = []) {
 		]
 	];
 
-	$host_groups = API::HostGroup()->get(['groupid', 'name']);
+	$host_groups = API::HostGroup()->get(['output' => ['groupid', 'name']]);
 
 	foreach ($host_groups as $host_group) {
 		$groups_rights[$host_group['groupid']] = [
@@ -201,7 +189,53 @@ function getHostGroupsRights(array $usrgrpids = []) {
 		);
 
 		while ($db_right = DBfetch($db_rights)) {
-			$groups_rights[$db_right['groupid']]['permission'] = $db_right['permission'];
+			if (array_key_exists($db_right['groupid'], $groups_rights)) {
+				$groups_rights[$db_right['groupid']]['permission'] = $db_right['permission'];
+			}
+		}
+	}
+
+	return $groups_rights;
+}
+
+/**
+ * Returns the list of permissions to the template groups for selected user groups.
+ *
+ * @param array $usrgrpids  An array of user group IDs.
+ *
+ * @return array
+ */
+function getTemplateGroupsRights(array $usrgrpids = []) {
+	$groups_rights = [
+		'0' => [
+			'permission' => PERM_NONE,
+			'name' => '',
+			'grouped' => '1'
+		]
+	];
+
+	$template_groups = API::TemplateGroup()->get(['output' => ['groupid', 'name']]);
+
+	foreach ($template_groups as $template_group) {
+		$groups_rights[$template_group['groupid']] = [
+			'permission' => PERM_NONE,
+			'name' => $template_group['name']
+		];
+	}
+
+	if ($usrgrpids) {
+		$db_rights = DBselect(
+			'SELECT r.id AS groupid,'.
+			'CASE WHEN MIN(r.permission)='.PERM_DENY.' THEN '.PERM_DENY.' ELSE MAX(r.permission) END AS permission'.
+			' FROM rights r'.
+			' WHERE '.dbConditionInt('r.groupid', $usrgrpids).
+			' GROUP BY r.id'
+		);
+
+		while ($db_right = DBfetch($db_rights)) {
+			if (array_key_exists($db_right['groupid'], $groups_rights)) {
+				$groups_rights[$db_right['groupid']]['permission'] = $db_right['permission'];
+			}
 		}
 	}
 
@@ -217,7 +251,7 @@ function getHostGroupsRights(array $usrgrpids = []) {
  *
  * @return array
  */
-function collapseHostGroupRights(array $groups_rights) {
+function collapseGroupRights(array $groups_rights) {
 	$groups = [];
 
 	foreach ($groups_rights as $groupid => $group_rights) {
@@ -266,22 +300,90 @@ function collapseHostGroupRights(array $groups_rights) {
 	return $groups_rights;
 }
 
+/**
+ * Returns the sorted list of the unique tag filters.
+ *
+ * @param array  $tag_filters
+ *
+ * @return array
+ */
+function uniqTagFilters(array $tag_filters) {
+	CArrayHelper::sort($tag_filters, ['groupid', 'tag', 'value']);
+
+	$prev_tag_filter = null;
+
+	foreach ($tag_filters as $key => $tag_filter) {
+		if ($prev_tag_filter !== null && $prev_tag_filter['groupid'] == $tag_filter['groupid']
+				&& ($prev_tag_filter['tag'] === '' || $prev_tag_filter['tag'] === $tag_filter['tag'])
+				&& ($prev_tag_filter['value'] === '' || $prev_tag_filter['value'] === $tag_filter['value'])) {
+			unset($tag_filters[$key]);
+		}
+		else {
+			$prev_tag_filter = $tag_filter;
+		}
+	}
+
+	return $tag_filters;
+}
+
+/**
+ * Returns the sorted list of the unique tag filters and group names.
+ * The list will be enriched by group names. Tag filters with filled tags or values will be overwritten empty.
+ *
+ * @param array  $tag_filters
+ * @param string $tag_filters[]['groupid']
+ * @param string $tag_filters[]['tag']
+ * @param string $tag_filters[]['value']
+ *
+ * @return array
+ */
+function collapseTagFilters(array $tag_filters) {
+	$tag_filters = uniqTagFilters($tag_filters);
+
+	$groupids = [];
+
+	foreach ($tag_filters as $tag_filter) {
+		$groupids[$tag_filter['groupid']] = true;
+	}
+
+	if ($groupids) {
+		$groups = API::HostGroup()->get([
+			'output' => ['name'],
+			'groupids' => array_keys($groupids),
+			'preservekeys' => true
+		]);
+
+		foreach ($tag_filters as $key => $tag_filter) {
+			if (array_key_exists($tag_filter['groupid'], $groups)) {
+				$tag_filters[$key]['name'] = $groups[$tag_filter['groupid']]['name'];
+			}
+			else {
+				unset($tag_filters[$key]);
+			}
+		}
+
+		CArrayHelper::sort($tag_filters, ['name', 'tag', 'value']);
+	}
+
+	return $tag_filters;
+}
+
 /**
  * Applies new permissions to the host groups.
  *
- * @param array  $groups_rights
- * @param string $groups_rights[<groupid>]['name']
- * @param int    $groups_rights[<groupid>]['permission']
- * @param int    $groups_rights[<groupid>]['grouped']    (optional)
- * @param array  $groupids
- * @param array  $groupids_subgroupids
- * @param int    $new_permission
+ * @param array  $groups_rights                           Array with host roup rights information.
+ * @param string $groups_rights[<groupid>]['name']        Name of the host group.
+ * @param int    $groups_rights[<groupid>]['permission']  Permission level.
+ * @param int    $groups_rights[<groupid>]['grouped']     (optional) If group is grouped with subgroups.
+ * @param array  $groupids                                Host group ID.
+ * @param array  $groupids_subgroupids                    Host group's subgroup IDs.
+ * @param int    $new_permission                          New permission level.
  *
  * @return array
  */
 function applyHostGroupRights(array $groups_rights, array $groupids = [], array $groupids_subgroupids = [],
 		$new_permission = PERM_NONE) {
-	// get list of host groups
+	// Get list of host groups.
 	$ex_groups_rights = getHostGroupsRights();
 	$ex_groups = [];
 
@@ -289,7 +391,7 @@ function applyHostGroupRights(array $groups_rights, array $groupids = [], array
 		$ex_groups[$ex_group_rights['name']] = $groupid;
 	}
 
-	// convert $groupids_subgroupids into $groupids
+	// Convert $groupids_subgroupids into $groupids.
 	foreach ($groupids_subgroupids as $groupid) {
 		if (!array_key_exists($groupid, $ex_groups_rights)) {
 			continue;
@@ -309,15 +411,101 @@ function applyHostGroupRights(array $groups_rights, array $groupids = [], array
 
 	$groupids = array_fill_keys($groupids, true);
 
-	// apply new permissions to all groups
+	// Apply new permissions to all groups.
 	foreach ($ex_groups_rights as $groupid => &$ex_group_rights) {
 		if ($groupid == 0) {
 			continue;
 		}
+
 		if (array_key_exists($groupid, $groupids)) {
 			$ex_group_rights['permission'] = $new_permission;
 			continue;
 		}
+
+		if (array_key_exists($groupid, $groups_rights)) {
+			$ex_group_rights['permission'] = $groups_rights[$groupid]['permission'];
+			continue;
+		}
+
+		$parent_group_name = $ex_group_rights['name'];
+
+		do {
+			$pos = strrpos($parent_group_name, '/');
+			$parent_group_name = ($pos === false) ? '' : substr($parent_group_name, 0, $pos);
+
+			if (array_key_exists($parent_group_name, $ex_groups)
+					&& array_key_exists($ex_groups[$parent_group_name], $groups_rights)) {
+				$parent_group_rights = $groups_rights[$ex_groups[$parent_group_name]];
+
+				if (array_key_exists('grouped', $parent_group_rights) && $parent_group_rights['grouped']) {
+					$ex_group_rights['permission'] = $parent_group_rights['permission'];
+					break;
+				}
+			}
+		}
+		while ($parent_group_name !== '');
+	}
+	unset($ex_group_rights);
+
+	CArrayHelper::sort($ex_groups_rights, [['field' => 'name', 'order' => ZBX_SORT_UP]]);
+
+	return $ex_groups_rights;
+}
+
+/**
+ * Applies new permissions to the template groups.
+ *
+ * @param array  $groups_rights                           Array with template group rights information.
+ * @param string $groups_rights[<groupid>]['name']        Name of the template group.
+ * @param int    $groups_rights[<groupid>]['permission']  Permission level.
+ * @param int    $groups_rights[<groupid>]['grouped']     (optional) If group is grouped with subgroups.
+ * @param array  $groupids                                Group ID.
+ * @param array  $groupids_subgroupids                    Group's subgroup IDs
+ * @param int    $new_permission                          New permission level.
+ *
+ * @return array
+ */
+function applyTemplateGroupRights(array $groups_rights, array $groupids = [], array $groupids_subgroupids = [],
+		$new_permission = PERM_NONE) {
+	// Get list of host groups.
+	$ex_groups_rights = getTemplateGroupsRights();
+	$ex_groups = [];
+
+	foreach ($ex_groups_rights as $groupid => $ex_group_rights) {
+		$ex_groups[$ex_group_rights['name']] = $groupid;
+	}
+
+	// Convert $groupids_subgroupids into $groupids.
+	foreach ($groupids_subgroupids as $groupid) {
+		if (!array_key_exists($groupid, $ex_groups_rights)) {
+			continue;
+		}
+
+		$groupids[] = $groupid;
+
+		$parent_group_name = $ex_groups_rights[$groupid]['name'].'/';
+		$parent_group_name_len = strlen($parent_group_name);
+
+		foreach ($ex_groups_rights as $groupid => $ex_group_rights) {
+			if (substr($ex_group_rights['name'], 0, $parent_group_name_len) === $parent_group_name) {
+				$groupids[] = $groupid;
+			}
+		}
+	}
+
+	$groupids = array_fill_keys($groupids, true);
+
+	// Apply new permissions to all groups.
+	foreach ($ex_groups_rights as $groupid => &$ex_group_rights) {
+		if ($groupid == 0) {
+			continue;
+		}
+
+		if (array_key_exists($groupid, $groupids)) {
+			$ex_group_rights['permission'] = $new_permission;
+			continue;
+		}
+
 		if (array_key_exists($groupid, $groups_rights)) {
 			$ex_group_rights['permission'] = $groups_rights[$groupid]['permission'];
 			continue;
