@@ -37,7 +37,7 @@ $actionForm = (new CForm())
 		->setArgument('eventsource', $data['eventsource'])
 		->getUrl()
 	)
-	->setAttribute('aria-labeledby', ZBX_STYLE_PAGE_TITLE)
+	->setAttribute('aria-labelledby', ZBX_STYLE_PAGE_TITLE)
 	->addVar('form', $data['form']);
 
 if ($data['actionid']) {
